==> qt6-webengine-debug-6.10.2-1-x86_64.pkg.tar.zst: usr/src/debug/qt6-webengine/qtwebengine/src/3rdparty/chromium/ui/events/keycodes/keyboard_code_conversion_x.h <==
// Copyright 2011 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef UI_EVENTS_KEYCODES_KEYBOARD_CODE_CONVERSION_X_H_
#define UI_EVENTS_KEYCODES_KEYBOARD_CODE_CONVERSION_X_H_

#include <stdint.h>


#include "ui/events/keycodes/dom/dom_key.h"
#include "ui/events/keycodes/keyboard_codes_posix.h"
#include "ui/events/keycodes/keycodes_x_export.h"
#include "ui/gfx/x/connection.h"
#include "ui/gfx/x/event.h"

namespace ui {

enum class DomCode : uint32_t;

KEYCODES_X_EXPORT KeyboardCode KeyboardCodeFromXKeyEvent(const x11::Event& xev);

KEYCODES_X_EXPORT KeyboardCode KeyboardCodeFromXKeysym(unsigned int keysym);

KEYCODES_X_EXPORT DomCode CodeFromXEvent(const x11::Event& xev);

// Returns a character on a standard US PC keyboard from an XEvent.
KEYCODES_X_EXPORT uint16_t GetCharacterFromXEvent(const x11::Event& xev);

// Returns DomKey and character from an XEvent.
KEYCODES_X_EXPORT DomKey GetDomKeyFromXEvent(const x11::Event& xev);

// Converts a KeyboardCode into an X KeySym.
KEYCODES_X_EXPORT int XKeysymForWindowsKeyCode(KeyboardCode keycode,
                                               bool shift);

// Returns a XKeyEvent keycode (scancode) for a KeyboardCode. Keyboard layouts
// are usually not injective, so inverse mapping should be avoided when
// practical. A round-trip keycode -> KeyboardCode -> keycode will not
// necessarily return the original keycode.
KEYCODES_X_EXPORT unsigned int XKeyCodeForWindowsKeyCode(
    KeyboardCode key_code,
    int flags,
    x11::Connection* connection);

// Converts an X keycode into ui::KeyboardCode.
KEYCODES_X_EXPORT KeyboardCode
DefaultKeyboardCodeFromHardwareKeycode(unsigned int hardware_code);

}  // namespace ui

#endif  // UI_EVENTS_KEYCODES_KEYBOARD_CODE_CONVERSION_X_H_

==> qt6-webengine-debug-6.11.0rc1-1-x86_64.pkg.tar.zst: usr/src/debug/qt6-webengine/qtwebengine/src/3rdparty/chromium/ui/events/keycodes/keyboard_code_conversion_x.h <==
// Copyright 2011 The Chromium Authors
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.

#ifndef UI_EVENTS_KEYCODES_KEYBOARD_CODE_CONVERSION_X_H_
#define UI_EVENTS_KEYCODES_KEYBOARD_CODE_CONVERSION_X_H_

#include <stdint.h>

#include "ui/events/keycodes/dom/dom_key.h"
#include "ui/events/keycodes/keyboard_codes_posix.h"
#include "ui/events/keycodes/keycodes_x_export.h"
#include "ui/gfx/x/connection.h"
#include "ui/gfx/x/event.h"
#include "ui/gfx/x/xinput.h"

namespace ui {

enum class DomCode : uint32_t;

KEYCODES_X_EXPORT KeyboardCode KeyboardCodeFromXKeyEvent(const x11::Event& xev);

KEYCODES_X_EXPORT KeyboardCode KeyboardCodeFromXKeysym(unsigned int keysym);

KEYCODES_X_EXPORT DomCode CodeFromXEvent(const x11::Event& xev);

// Returns a character on a standard US PC keyboard from an XEvent.
KEYCODES_X_EXPORT uint16_t GetCharacterFromXEvent(const x11::Event& xev);

// Returns DomKey and character from an XEvent.
KEYCODES_X_EXPORT DomKey GetDomKeyFromXEvent(const x11::Event& xev);

// Converts a KeyboardCode into an X KeySym.
KEYCODES_X_EXPORT int XKeysymForWindowsKeyCode(KeyboardCode keycode,
                                               bool shift);

// Returns a XKeyEvent keycode (scancode) for a KeyboardCode. Keyboard layouts
// are usually not injective, so inverse mapping should be avoided when
// practical. A round-trip keycode -> KeyboardCode -> keycode will not
// necessarily return the original keycode.
KEYCODES_X_EXPORT unsigned int XKeyCodeForWindowsKeyCode(
    KeyboardCode key_code,
    int flags,
    x11::Connection* connection);

// Converts an X keycode into ui::KeyboardCode.
KEYCODES_X_EXPORT KeyboardCode
DefaultKeyboardCodeFromHardwareKeycode(unsigned int hardware_code);

// Returns the state of an XI2 event, including the keyboard group.
KEYCODES_X_EXPORT uint32_t
GetXI2StateFromEvent(const x11::Input::DeviceEvent& xievent);

// Returns the keyboard group from the core state.
KEYCODES_X_EXPORT int XkbGroupForCoreState(int state);

}  // namespace ui

#endif  // UI_EVENTS_KEYCODES_KEYBOARD_CODE_CONVERSION_X_H_
